@@ -143,26 +143,11 @@ class BaseAEADCipher(BaseCipher):
 
     def unpack(self, data: bytes) -> bytes:
         """解包udp"""
-
-        data_len = len(data)
-        tag_idx = data_len - self.TAG_SIZE
-        salt, payload, tag = (
-            data[: self.SALT_SIZE],
-            data[self.SALT_SIZE : tag_idx],
-            data[tag_idx:],
-        )
-        decrypt_func = self._init_decrypt_func(salt)
-        return decrypt_func(payload, tag)
+        return self.decrypt(data)
 
     def pack(self, data: bytes) -> bytes:
         """压udp包"""
-        ret = bytearray()
-        salt, encrypt_func = self._init_encrypt_func(None)
-        ret.extend(salt)
-        chunk, tag = encrypt_func(data)
-        ret.extend(chunk)
-        ret.extend(tag)
-        return bytes(ret)
+        return self.encrypt(data)
 
     @classmethod
     def tcp_first_data_len(cls):
